<?php 
/*
Plugin Name: WP-TwitterSearch
Version: 1.2.1
Plugin URI: http://paperkilledrock.com/projects/WP-TwitterSearch
Description: Displays the latest results based on a twitter search. Options include setting multiple search terms and limiting tweets shown. Add the widget to your sidebar or use <code>&lt;?php wp_twittersearch_feed(); ?&gt;</code> in your template.
Author: James Fleeting
Author URI: http://jamesfleeting.com
*/

/*  Copyright 2009  James Fleeting (james.fleeting[at]gmail.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

//lets go ahead and define a few things for easy updating...
define(WPTS_CURRENT_VERSION, "1.2.1");
define(WPTS_PLUGIN_URL, "http://paperkilledrock.com/projects/WP-TwitterSearch");

//guess we should add some wordpress hooks and actions
register_activation_hook(__FILE__,'set_wptwittersearch_options');
register_deactivation_hook(__FILE__,'unset_wptwittersearch_options');
add_action('admin_menu', 'wp_twitter_search_menu');
add_action('wp_dashboard_setup', 'add_wptwittersearch_dashboard_widgets' );
add_action("plugins_loaded", "wp_twitter_search_widget_init");

  //on plugin activation create options in db
  function set_wptwittersearch_options() {
    add_option('wptwittersearch_limit', '5'); //add option to wp_options -> limit default
    add_option('wptwittersearch_terms', 'wordpress plugins'); //add option to wp_options -> terms default
    add_option('wptwittersearch_author', ''); //add option to wp_options -> author default
    add_option('wptwittersearch_date', '1'); //add option to wp_options -> date default
    add_option('wptwittersearch_tweetsource', '0'); //add option to wp_options -> source
    add_option('wptwittersearch_linklove', '0'); //add option to wp_options -> link love default
  }
  
  //on plugin deactivation delete options from db
  function unset_wptwittersearch_options() {
    delete_option('wptwittersearch_limit');
    delete_option('wptwittersearch_terms');
    delete_option('wptwittersearch_author');
    delete_option('wptwittersearch_date');
    delete_option('wptwittersearch_tweetsource');
    delete_option('wptwittersearch_linklove');
  }
  
  //create menu items
  function wp_twitter_search_menu() {
    add_menu_page('WP-TwitterSearch Options', 'TwitterSearch', 8, __FILE__, 'wp_twitter_search_options', plugins_url('wp-twittersearch/wptwittersearch_18.png'));
    add_submenu_page(__FILE__, 'WP-TwitterSearch -> Options', 'Options', 8, __FILE__, 'wp_twitter_search_options');
    add_submenu_page(__FILE__, 'WP-TwitterSearch -> About', 'About', 8, 'wp-twitter-search-about.php', 'wp_twitter_search_about');
  }
  
  //create dashboard widgets
  function add_wptwittersearch_dashboard_widgets() {
    wp_add_dashboard_widget('wptwittersearch', 'WP-TwitterSearch', 'wp_twitter_search_dashboard', $control_callback = null);
  } //add_wptwittersearch_dashboard_widgets
  
  //search dashboard widget
  function wp_twitter_search_dashboard() {
    echo wp_twittersearch_feed();
    echo '<span class="wpts_linklove">Powered by <a href="' . WPTS_PLUGIN_URL . '">WP-TwitterSearch</a></span>';
  } //wp_twitter_search_dashboard
  
  //the sidebar widget
  function wp_twitter_search_widget($args) {
    extract($args, EXTR_SKIP);
    echo $before_widget;
    wp_twittersearch_feed();
    echo $after_widget;
  }
  
  //register sidebar widget
  function wp_twitter_search_widget_init() {
    //wp_register_sidebar_widget(wptwittersearch_widget, __('WP-TwitterSearch'), 'wp_twitter_search_widget');
    wp_register_sidebar_widget(wptwittersearch_widget, 'TwitterSearch', 'wp_twitter_search_widget', array('description' => __('Add TwitterSearch To Your Sidebar.')) );
  }
  
  //user defined options (values are stored in database in wp_options)
  function wp_twitter_search_options() {
    // If updated options were saved.
    if ( isset($_GET['updated']) ) {
      echo '<div id="message" class="updated fade"><p>Options Saved!</p></div>';
    }
?>

    <div class="wrap">
      <h2>WP-TwitterSearch Options</h2>

        <form method="post" action="options.php">
        <?php wp_nonce_field('update-options'); ?>

          <table class="form-table">
            <tr valign="top">
              <th scope="row">Search Terms</th>
              <td><input type="text" name="wptwittersearch_terms" value="<?php echo get_option('wptwittersearch_terms'); ?>" /></td>
            </tr>
            
            <tr valign="top">
              <th scope="row">From This Person <small>(optional)</small></th>
              <td><input type="text" name="wptwittersearch_author" value="<?php echo get_option('wptwittersearch_author'); ?>" /></td>
            </tr>
 
            <tr valign="top">
              <th scope="row">Limit Tweets</th>
              <td><input type="text" name="wptwittersearch_limit" value="<?php echo get_option('wptwittersearch_limit'); ?>" /></td>
            </tr>
            
            <tr valign="top">
              <th scope="row">Display Tweet Date?</th>
              <td><select name="wptwittersearch_date">
                <option value="1"<?php if (get_option('wptwittersearch_date') == '1') { echo ' selected'; } ?>>Yes</option>
								<option value="0"<?php if (get_option('wptwittersearch_date') == '0') { echo ' selected'; } ?>>No</option>
							</select></td>
            </tr>
            
            <tr valign="top">
              <th scope="row">Display Tweet Source? (ex: posted via web)</th>
              <td><select name="wptwittersearch_tweetsource">
                <option value="1"<?php if (get_option('wptwittersearch_tweetsource') == '1') { echo ' selected'; } ?>>Yes</option>
								<option value="0"<?php if (get_option('wptwittersearch_tweetsource') == '0') { echo ' selected'; } ?>>No</option>
							</select></td>
            </tr>            
            
            <tr valign="top">
              <th scope="row">Credit WP-TwitterSearch</th>
              <td><select name="wptwittersearch_linklove">
                <option value="1"<?php if (get_option('wptwittersearch_linklove') == '1') { echo ' selected'; } ?>>Yes</option>
								<option value="0"<?php if (get_option('wptwittersearch_linklove') == '0') { echo ' selected'; } ?>>No</option>
							</select></td>
            </tr>
          </table>

          <input type="hidden" name="action" value="update" />
          <input type="hidden" name="page_options" value="wptwittersearch_terms,wptwittersearch_author,wptwittersearch_limit,wptwittersearch_date,wptwittersearch_tweetsource,wptwittersearch_linklove" />

          <p class="submit">
            <input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
          </p>
        </form>
        <h2>Search Preview</h2>
          <span><?php echo wp_twittersearch_feed(); ?></span>
    </div>

<?php   
  } //wp_twitter_search_options

  //about wptwittersearch plugin
  function wp_twitter_search_about() {
?>
    <div class="wrap">
      <h2>WP-TwitterSearch About</h2>
        <p>WP-TwitterSearch gives you an easy way to display twitter search results based on defined keywords. You are currently able to use the template code: <code>&lt;?php wp_twittersearch_feed(); ?&gt;</code> anywhere in your template files to display the results.</p>
      <h3>TODO</h3>
        <ul style="list-style:square inside;padding:0 0 0 15px">
          <li>Add Widget Support</li>
          <li>More options based on twitter's advanced search</li>
          <li>Display results from your username and tags from a post</li>
          <li>Cache the result for a period of time?</li>
        </ul>
          
        <p>Current Version: v<?php echo WPTS_CURRENT_VERSION; ?> | Developed by: <a href="http://jamesfleeting.com">James Fleeting</a> | 
          Latest version and docs can be found at <a href="<?php echo WPTS_PLUGIN_URL; ?>">paperkilledrock.com</a>.</p>
    </div>
<?php } //wp_twitter_search_credits
  
  // The heart of the plugin.
  function wp_twittersearch_feed() {
    //get your saved search terms
    $search_terms = get_option('wptwittersearch_terms');
    //limit the number of tweets
    $limit_tweets = get_option('wptwittersearch_limit');
    //only tweets from this author
    $search_author = get_option('wptwittersearch_author');
    $show_usernames = 1; //show usernames
    //hashtag support and combine search terms using OR operator
    $search_terms = str_replace('#', '%23', $search_terms);
    $search_terms = str_replace(' ', '+OR+', $search_terms);
    //searching twitter...
    $twitter_feed = 'http://search.twitter.com/search.atom?q=' . $search_terms . '&from=' . $search_author . '&rpp=' . $limit_tweets;
    $twitter_feed = file_get_contents($twitter_feed);
    $twitter_feed= html_entity_decode($twitter_feed); 
    $clean = explode('<entry>', $twitter_feed);
    $amount = count($clean) - 1;
    
    if (get_option('wptwittersearch_author')) { echo '<h2>Tweets from: <a href="#author">@' . $search_author . '</a></h2>'; }
    echo '<ul>';
    
    for ($i = 1; $i <= $amount; $i++) {
      $entry_close           = explode('</entry>', $clean[$i]);
      //lets get the twitter post
      $clean_content_1       = explode('<content type="html">', $entry_close[0]);
      $clean_content         = explode('</content>', $clean_content_1[1]);
      //grab the date it was posted
      $clean_date_2          = explode('<published>', $entry_close[0]);
      $clean_date_1          = explode('</published>', $clean_date_2[1]);
      $clean_date            = date('m/d/y g:ia', strtotime($clean_date_1[0]));
      //and who posted it
      $clean_name_2          = explode('<name>', $entry_close[0]);
      $clean_name_1          = explode('(', $clean_name_2[1]);
      $clean_name            = explode(')</name>', $clean_name_1[1]);
      //they posted it via 
      $clean_tweetsource_1   = explode('<twitter:source>', $entry_close[0]);
      $clean_tweetsource     = explode('</twitter:source>', $clean_tweetsource_1[1]);
      //and the permalink to view the post
      $clean_uri_1           = explode('<uri>', $entry_close[0]);
      $clean_uri             = explode('</uri>', $clean_uri_1[1]);
      
      //show and link usernames
      echo '<li>';
      if (!get_option('wptwittersearch_author')) { 
        echo '<span class="tweetAuthor"><a href="' . $clean_uri[0] . '">' . $clean_name[0] . '</a></span>: ';
      }
      
      echo $clean_content[0];
      //do we show the date?
      if (get_option('wptwittersearch_date') == '1') {
        echo '<span class="tweetDate">' . $clean_date . '</span>';
      }
      //do we show the source?
      if (get_option('wptwittersearch_tweetsource') == '1') {
        echo '&nbsp;via <span class="tweetSource">' . $clean_tweetsource[0] . '</span>';
      }
      
      echo '</li>';
    }
    //share the love man...
    if (get_option('wptwittersearch_linklove') == '1') {
      echo '<li class="wpts_linklove">Powered by <a href="' . WPTS_PLUGIN_URL .'">WP-TwitterSearch</a></li>';
    }
    echo '</ul>';
  } //wp_twittersearch_feed
?>